bayespy.inference.vmp.nodes.stochastic.Stochastic.broadcasting_multiplier
=========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.broadcasting_multiplier